@@ -19,7 +19,7 @@ import (
 type PagerMode interface {
 	onKey(key twin.KeyCode)
 	onRune(char rune)
-	drawFooter(statusText string, spinner string)
+	drawFooter(filenameText string, statusText string, spinner string)
 }
 
 type StatusBarOption int
@@ -37,6 +37,8 @@ type eventSpinnerUpdate struct {
 	spinner string
 }
 
+// Or we switched readers. Or something else happened that requires us to
+// recheck our reader.
 type eventMoreLinesAvailable struct{}
 
 // Either reading, highlighting or both are done. Check reader.Done() and
@@ -320,15 +322,27 @@ func renderHelpText(help string) []twin.StyledRune {
 //
 // Single quoted parts of the help text will be bolded.
 //
-// footer example value: "file.txt: 123 lines  0%"
+// prefix example value: "[1/3] "
+// filename example value: "file.txt"
+// status example value: ": 123 lines  0%"
 // help example value: "Press 'h' for help, 'q' to quit"
-func (p *Pager) setFooter(footer string, help string) {
+func (p *Pager) setFooter(prefix string, filename string, status string, help string) {
 	width, height := p.screen.Size()
 
 	pos := 0
 
-	// File name and percentage, no keyboard shortcut highlighting
-	for _, token := range footer + "  " {
+	// Prefix (multiple open files)
+	for _, token := range prefix {
+		pos += p.screen.SetCell(pos, height-1, twin.NewStyledRune(token, statusbarStyle))
+	}
+
+	// File name
+	for _, token := range filename {
+		pos += p.screen.SetCell(pos, height-1, twin.NewStyledRune(token, statusbarFileStyle))
+	}
+
+	// percentage,
+	for _, token := range status + "  " {
 		pos += p.screen.SetCell(pos, height-1, twin.NewStyledRune(token, statusbarStyle))
 	}
 
@@ -404,6 +418,32 @@ func (p *Pager) handleScrolledDown() {
 	}
 }
 
+func (p *Pager) handleMoreLinesAvailable() {
+	// Without the isViewing() check, following will continue while
+	// searching, and I prefer it to stop so people can see what they
+	// are searching in.
+	if !p.isViewing() || p.TargetLine == nil {
+		return
+	}
+
+	// The user wants to scroll down to a specific line number
+	lineCount := p.Reader().GetLineCount()
+	if lineCount == 0 {
+		// No lines yet, keep waiting
+		return
+	}
+
+	if linemetadata.IndexFromLength(lineCount).IsBefore(*p.TargetLine) {
+		// Not there yet, keep scrolling
+		p.scrollToEnd()
+		return
+	}
+
+	// We see the target, scroll to it
+	p.scrollPosition = NewScrollPositionFromIndex(*p.TargetLine, "goToTargetLine")
+	p.setTargetLine(nil)
+}
+
 // Except for setting TargetLine, this method also syncs with the reader so that
 // the reader knows how many lines it needs to fetch.
 func (p *Pager) setTargetLine(targetLine *linemetadata.Index) {
@@ -619,20 +659,7 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 			return
 
 		case eventMoreLinesAvailable:
-			// Without the isViewing() check, following will continue while
-			// searching, and I prefer it to stop so people can see what they
-			// are searching in.
-			if p.isViewing() && p.TargetLine != nil {
-				// The user wants to scroll down to a specific line number
-				if linemetadata.IndexFromLength(p.Reader().GetLineCount()).IsBefore(*p.TargetLine) {
-					// Not there yet, keep scrolling
-					p.scrollToEnd()
-				} else {
-					// We see the target, scroll to it
-					p.scrollPosition = NewScrollPositionFromIndex(*p.TargetLine, "goToTargetLine")
-					p.setTargetLine(nil)
-				}
-			}
+			p.handleMoreLinesAvailable()
 
 		case eventMaybeDone:
 			// Man pages come pre-formatted for the screen width, and line
@@ -654,6 +681,8 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 			log.Warnf("Unhandled event type: %v", event)
 		}
 	}
+
+	log.Info("Pager main loop done")
 }
 
 // The height parameter is the terminal height minus the height of the user's
@@ -725,7 +754,7 @@ func (p *Pager) fitsOnOneScreen() bool {
 
 	lines := reader.GetLines(linemetadata.Index{}, reader.GetLineCount())
 	for _, line := range lines.Lines {
-		rendered := line.HighlightedTokens(twin.StyleDefault, twin.StyleDefault, search.Search{}).StyledRunes
+		rendered := line.HighlightedTokens(twin.StyleDefault, twin.StyleDefault, search.Search{}, width+1).StyledRunes
 		if len(rendered) > width {
 			// This line is too long to fit on one screen line, no fit
 			return false
